@@ -22,13 +22,14 @@ class DeployFormatter(object):
         strategy = format_strategies.get(format)
 
         if not strategy:
-            raise ValueError(
-                "Allowed deploy formats[{0}]. Given {1}".format(
-                  "|".join(FORMATS),
-                  format,
-                )
+            msg_fmt = "Allowed deploy formats[{0}]. Given {1}"
+            msg = msg_fmt.format(
+                "|".join(self.FORMATS()),
+                format,
             )
 
+            raise ValueError(msg)
+
         return strategy
 
     @classmethod
@@ -36,7 +37,7 @@ class DeployFormatter(object):
         return [
             cls.DEFAULT,
             cls.ENV_VARS,
-       ]
+        ]
 
     def env_vars_format(self, deploy):
         to_env_vars_translation_args = [
@@ -49,7 +50,6 @@ class DeployFormatter(object):
             ('FLOW_DEPLOY_PREVIOUS_VERSION_COMMIT', 'previous_commit', ''),
         ]
 
-
         env_vars = {}
 
         for arg in to_env_vars_translation_args:
@@ -70,13 +70,11 @@ class DeployFormatter(object):
               value=quote(var_val),
             )
 
-
             print(line, file=buffer)
 
         buffer.seek(0)
         return buffer.read()
 
-
     def default_format(self, src_deploy):
         deploy = {
             'id': 0,
@@ -101,6 +99,7 @@ Created deploy:
             **deploy
         )
 
+
 def notify_created_deploy(deploy):
     formatter = DeployFormatter(DeployFormatter.DEFAULT)
     click.echo(formatter.format(deploy))
@@ -113,8 +112,8 @@ def project_code_option(*args, **kargs):
     project_code_param = "--project-code"
     paramsdecl = args
 
-    if not project_code_param in args:
-     paramsdecl = args + (project_code_param, )
+    if project_code_param not in args:
+        paramsdecl = args + (project_code_param, )
 
     return click.option(
         *paramsdecl,
