@@ -1,6 +1,5 @@
 import click
 
-from convisoappsec.flow import api
 from convisoappsec.flow.version_searchers import TimeBasedVersionSearcher
 from convisoappsec.flow.version_control_system_adapter import GitAdapter
 from convisoappsec.flowcli.context import pass_flow_context
@@ -24,7 +23,10 @@ from convisoappsec.flowcli.deploy.create.with_.tag_tracker.context import (
 @pass_tag_tracker_context
 @pass_create_context
 @pass_flow_context
-def time_(flow_context, create_context, tag_tracker_context, project_code, attach_diff):
+def time_(
+    flow_context, create_context, tag_tracker_context,
+    project_code, attach_diff
+):
     try:
         repository_dir = tag_tracker_context.repository_dir
         git_adapter = GitAdapter(repository_dir)
