@@ -7,6 +7,7 @@ from convisoappsec.flow import GitAdapter
 from convisoappsec.flow import api
 from convisoappsec.flowcli.common import project_code_option
 
+
 @click.command()
 @help_option
 @project_code_option()
@@ -20,7 +21,8 @@ from convisoappsec.flowcli.common import project_code_option
     "-p",
     "--previous-commit",
     required=False,
-    help="If no value is given the value is retrieved from the lastest deploy at flow application.",
+    help="""If no value is given, the value is retrieved from the lastest
+    deploy at flow application.""",
 )
 @click.option(
     "-r",
@@ -74,4 +76,4 @@ def values(
             create_context.output_formatter.format(deploy)
         )
     except Exception as e:
-        raise click.ClickException(str(e)) from e
\ No newline at end of file
+        raise click.ClickException(str(e)) from e
