@@ -1,23 +1,27 @@
-import sys
 from contextlib import suppress
 from pathlib import Path
 import tempfile
+import tarfile
 import docker
 
 
 class SASTBox(object):
     REGISTRY = 'docker.convisoappsec.com'
     TAG = 'latest'
-    WORKSPACE_DIR_PATTERN = 'sastbox_workspace*'
-    WORKSPACE_REPORT_PATH = ["output", "reports"]
+    CONTAINER_REPORTS_DIR = '/reports'
+    CONTAINER_CODE_DIR = '/code'
+
+    WORKSPACE_REPORT_PATH = ["reports"]
     JSON_REPORT_PATTERN = '*.jsonreporter*.json'
     SUCCESS_EXIT_CODE = 0
+    USER_ENV_VAR = "USER"
 
     def __init__(self):
         self.docker = docker.from_env(
             version="auto"
         )
 
+        self.container = None
 
     def login(self, password, username='AWS'):
         login_args = {
@@ -30,7 +34,9 @@ class SASTBox(object):
         login_result = self.docker.login(**login_args)
         return login_result
 
-    def run_scan_diff(self, code_dir, current_commit, previous_commit, log=None):
+    def run_scan_diff(
+        self, code_dir, current_commit, previous_commit, log=None
+    ):
         return self._scan_diff(
             code_dir, current_commit, previous_commit, log
         )
@@ -54,11 +60,12 @@ class SASTBox(object):
         '''
         size = self.size
         layers = {}
-        for line in self.docker.api.pull(self.image, tag=self.TAG, stream=True, decode=True):
+        for line in self.docker.api.pull(
+            self.image, tag=self.TAG, stream=True, decode=True
+        ):
             status = line.get('status', '')
             detail = line.get('progressDetail', {})
 
-
             if status == 'Downloading':
                 with suppress(Exception):
                     layer_id = line.get('id')
@@ -72,52 +79,58 @@ class SASTBox(object):
 
                         if (current/total) > 0.98 and not layer.get('done'):
                             yield current
-                            layer.update( { 'done': True } )
+                            layer.update({'done': True})
 
         yield size
 
-
     def _scan_diff(self, code_dir, current_commit, previous_commit, log):
-        tempdir = tempfile.mkdtemp()
-
         environment = {
-            'CURRENT_COMMIT': current_commit,
             'PREVIOUS_COMMIT': previous_commit,
+            'CURRENT_COMMIT': current_commit,
+            'SASTBOX_REPORTS_DIR': self.CONTAINER_REPORTS_DIR,
+            'SASTBOX_REPORT_PATTERN': '/tmp/sastbox_workspace*/output/reports/*.jsonreporter*.json',  # noqa: E501
+            'SASTBOX_CODE_DIR': self.CONTAINER_CODE_DIR,
         }
 
-        volumes = {
-            code_dir: {
-                'bind': '/code',
-                'mode': 'ro'
-            },
-            tempdir: {
-                'bind': '/tmp',
-                'mode': 'rw'
-            }
-        }
+        command = '''
+            ruby main.rb -c $SASTBOX_CODE_DIR --diff=$PREVIOUS_COMMIT,$CURRENT_COMMIT -q -a && \
+            mkdir -p $SASTBOX_REPORTS_DIR && \
+            cp $(find $SASTBOX_REPORT_PATTERN) $SASTBOX_REPORTS_DIR
+        '''  # noqa: E501
 
-        command = 'main.rb -c /code --diff={PREVIOUS_COMMIT},{CURRENT_COMMIT}  -q -a'.format(
-            **environment
-        )
-
-
-        run_args = {
+        create_args = {
             'image': self.image,
-            'entrypoint': 'ruby',
-            'command': command,
-            #'environment': environment,
-            'volumes': volumes,
+            'entrypoint': ['bash', '-c'],
+            'command': [command],
             'tty': True,
             'detach': True,
+            'environment': environment,
         }
 
-        container = self.docker.containers.run(**run_args)
+        self.container = self.docker.containers.create(**create_args)
+        # previously create source code tar ball
+        source_code_tarball_file = tempfile.TemporaryFile()
+        source_code_tarball = tarfile.open(
+            mode="w|gz", fileobj=source_code_tarball_file
+        )
 
-        for line in container.logs(stream=True):
+        source_code_tarball.add(
+            name=code_dir,
+            arcname=self.CONTAINER_CODE_DIR,
+        )
+
+        source_code_tarball.close()
+
+        source_code_tarball_file.seek(0)
+        self.container.put_archive("/", source_code_tarball_file)
+        source_code_tarball_file.close()
+        self.container.start()
+
+        for line in self.container.logs(stream=True):
             if log:
                 log(line, new_line=False)
 
-        wait_result = container.wait()
+        wait_result = self.container.wait()
         status_code = wait_result.get('StatusCode')
 
         if not status_code == self.SUCCESS_EXIT_CODE:
@@ -125,21 +138,35 @@ class SASTBox(object):
                 'SASTBox exiting with error status code'
             )
 
+        chunks, _ = self.container.get_archive(
+            self.CONTAINER_REPORTS_DIR
+        )
+
+        reports_tarball_file = tempfile.TemporaryFile()
+
+        for chunk in chunks:
+            reports_tarball_file.write(chunk)
+
+        tempdir = tempfile.mkdtemp()
+        reports_tarball_file.seek(0)
+        reports_tarball = tarfile.open(mode="r|", fileobj=reports_tarball_file)
+        reports_tarball.extractall(path=tempdir)
+        reports_tarball.close()
+        reports_tarball_file.close()
+
         return self._list_reports_paths(tempdir)
 
     @property
     def image(self):
         return "%s/sastbox" % self.REGISTRY
 
+    def __del__(self):
+        with suppress(Exception):
+            self.container.remove(v=True, force=True)
+
     @classmethod
     def _list_reports_paths(cls, root_dir):
-        sastbox_root_dir = Path(root_dir)
-        sastbox_workspaces_dir = sastbox_root_dir.glob(cls.WORKSPACE_DIR_PATTERN)
+        sastbox_reports_dir = Path(root_dir, *cls.WORKSPACE_REPORT_PATH)
 
-        for workspace_dir in sastbox_workspaces_dir:
-            sastbox_reports_dir = Path(
-                workspace_dir, *cls.WORKSPACE_REPORT_PATH
-            )
-
-            for report in sastbox_reports_dir.glob(cls.JSON_REPORT_PATTERN):
-                yield report
+        for report in sastbox_reports_dir.glob(cls.JSON_REPORT_PATTERN):
+            yield report
